bayespy.inference.vmp.nodes.categorical.CategoricalDistribution.plates_to_parent
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. automethod:: CategoricalDistribution.plates_to_parent